@@ -1,6 +1,5 @@
+from allauth.socialaccount.providers.hubic.provider import HubicProvider
 from allauth.socialaccount.providers.oauth2.urls import default_urlpatterns
 
-from .provider import HubicProvider
-
 
 urlpatterns = default_urlpatterns(HubicProvider)
